# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .lng_lat import LngLat
from .us_address import UsAddress
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AppointmentLocation(UniversalBaseModel):
    location: LngLat
    address: UsAddress
    code: str
    name: str
    iana_timezone: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
